# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`clamav`](#clamav): Installs the command line ClamAV anti-virus scanner.
* [`clamav::set_schedule`](#clamavset_schedule): Allows you to set a schedule for ClamAV to run a check on your system via cron

## Classes

### clamav

If you wish to schedule a virus scan, you will need to create a cron job that
is appropriate, or drop a script into the cron.* directory that is
appropriate.

#### Parameters

The following parameters are available in the `clamav` class.

##### `enable`

Data type: `Boolean`

Disables/Enables clamav

* Toggles freshclam/clamscan cronjobs, selbooleans, rsync, and package
  installation.

Default value: `true`

##### `manage_group_and_user`

Data type: `Boolean`

Optionally manage the clamav user and group.

Default value: `true`

##### `clamav_user`

Data type: `String`

The clamav user.

Default value: 'clam'

##### `clamav_group`

Data type: `String`

The clamav group.

Default value: 'clam'

##### `package_name`

Data type: `String`

The name of clamav rpm package.

Default value: 'clamav'

##### `enable_freshclam`

Data type: `Boolean`

If true, will enable the freshclam cron job.

Default value: `false`

##### `enable_data_rsync`

Data type: `Boolean`

If true, will use the SIMP rsync subsystem to pull down clamav DAT files.

* NOTE: `$enable_freshclam` takes precedence

Default value: `false`

##### `schedule_scan`

Data type: `Boolean`

If true, will enable the scheduled system scan.

* The default targets are *extremely* conservative so you will probably
  want to adjust this.

Default value: `true`

##### `rsync_source`

Data type: `String`

The rsync server source path for the clamav definitions.

* Setting this parameter to an empty String will disable the clamav rsync.

Default value: "clamav_${::environment}/"

##### `rsync_server`

Data type: `Simplib::Host`

The hostname or IP of the rsync server providing clamav definitions.

Default value: simplib::lookup('simp_options::rsync::server', { 'default_value' => '127.0.0.1' })

##### `rsync_timeout`

Data type: `Integer`

The amount of time, in seconds, to wait for rsync to respond.

Default value: simplib::lookup('simp_options::rsync::timeout', { 'default_value' => 2 })

##### `package_ensure`

Data type: `String[1]`

The value used for package ensure attribute.

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })

### clamav::set_schedule

* All 'yes/no' variables have been translated to 'true/false' for consistency.

* Defaults to weekly.

* **See also**
clamscan(1)
for any undefined variables.

#### Parameters

The following parameters are available in the `clamav::set_schedule` class.

##### `enable`

Data type: `Boolean`

Enables/Disables the clamscan cronjob.  Defaults to true.

Default value: simplib::lookup('clamav::enable', { 'default_value' => true})

##### `minute`

Data type: `Simplib::Cron::Minute`



Default value: '32'

##### `hour`

Data type: `Simplib::Cron::Hour`



Default value: '5'

##### `monthday`

Data type: `Simplib::Cron::MonthDay`



Default value: '*'

##### `month`

Data type: `Simplib::Cron::Month`



Default value: '*'

##### `weekday`

Data type: `Simplib::Cron::Weekday`



Default value: '0'

##### `nice_level`

Data type: `Integer`

The system 'nice' level at which to run the virus scan.

Default value: 19

##### `scan_targets`

Data type: `Array[Stdlib::Absolutepath]`

An array of directories upon which to perform this scan.

Default value: ['/tmp','/var/tmp','/dev/shm']

##### `official_db_only`

Data type: `Boolean`



Default value: `true`

##### `logfile`

Data type: `Stdlib::Absolutepath`



Default value: '/var/log/clamscan.log'

##### `recursive`

Data type: `Boolean`



Default value: `true`

##### `cross_fs`

Data type: `Boolean`



Default value: `true`

##### `summary`

Data type: `Boolean`



Default value: `false`

##### `infected_only`

Data type: `Boolean`



Default value: `true`

##### `bytecode`

Data type: `Boolean`



Default value: `true`

##### `bytecode_unsigned`

Data type: `Boolean`



Default value: `false`

##### `bytecode_timeout`

Data type: `Integer`



Default value: 60000

##### `detect_pua`

Data type: `Boolean`



Default value: `false`

##### `exclude_pua`

Data type: `Array[String]`



Default value: []

##### `include_pua`

Data type: `Array[String]`



Default value: []

##### `max_files`

Data type: `Integer`



Default value: 10000

##### `max_filesize`

Data type: `Integer`

The maximum archive size to scan, in megabytes.

Default value: 25

##### `max_scansize`

Data type: `Integer`

The maximum scanned file size to scan, in megabytes.

Default value: 100

##### `max_recursion`

Data type: `Integer`



Default value: 16

##### `max_dir_recursion`

Data type: `Integer`



Default value: 15

##### `logrotate`

Data type: `Boolean`

Enable the use of the SIMP logrotate capabilities.

Default value: simplib::lookup('simp_options::logrotate', { 'default_value' => false })

