# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`logrotate`](#logrotate): Configure LogRotate global options  Use ``logrotate::rule`` for specific configuration options.

**Defined types**

* [`logrotate::rule`](#logrotaterule): Add a LogRotate Configuration  If options have a 'no' variant, then the no variant will be set if you set the primary value to false  The ``l

**Data types**

* [`Logrotate::Periods`](#logrotateperiods): Allowed time intervals for logrotate
* [`Logrotate::Size`](#logrotatesize): Size of a log in bytes, kilobytes, megabytes or gigabytes

## Classes

### logrotate

Configure LogRotate global options

Use ``logrotate::rule`` for specific configuration options.

#### Parameters

The following parameters are available in the `logrotate` class.

##### `rotate_period`

Data type: `Logrotate::Periods`

How often to rotate the logs

Default value: 'weekly'

##### `rotate`

Data type: `Integer[0]`

The number of times to rotate the logs before removing them from the
system

Default value: 4

##### `create`

Data type: `Boolean`

Create new log files if they do not exist

Default value: `true`

##### `compress`

Data type: `Boolean`

Compress the logs upon rotation

Default value: `true`

##### `configdir`

Data type: `Stdlib::Absolutepath`

The primary directory for SIMP-managed configuration files.

Default value: '/etc/logrotate.simp.d'

##### `include_dirs`

Data type: `Array[Stdlib::Absolutepath]`

Directories to include in your logrotate configuration

* ``$logrotate::configdir`` is always included and is listed first
* Be sure to include ``/etc/logrotate.d`` in this list if you
  override the default.

Default value: [ '/etc/logrotate.d' ]

##### `manage_wtmp`

Data type: `Boolean`

Set to ``false`` if you do not want ``/var/log/wtmp`` to be managed by
logrotate

Default value: `true`

##### `dateext`

Data type: `Boolean`

Use ``dateext`` as the suffix for rotated files

Default value: `true`

##### `dateformat`

Data type: `String[1]`

The format of the date to be appended

* Leaving as is allows for multiple rotations per day

Default value: '-%Y%m%d.%s'

##### `dateyesterday`

Data type: `Optional[Boolean]`

Say 'yesterday' instead of the date

Default value: `undef`

##### `maxsize`

Data type: `Optional[Logrotate::Size]`

The default maximum size of a logfile

Default value: `undef`

##### `minsize`

Data type: `Optional[Logrotate::Size]`

The default minimum size of a logfile

* Overrides the ``maxsize`` setting

Default value: `undef`

##### `package_ensure`

Data type: `String[1]`

The ensure status of packages to be installed

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })

##### `logger_service`

Data type: `String[1]`

The service that controls system logging

* This is used by the ``logrotate::rule`` define to note the name of the
  service to be restarted if, and only if, the default lastaction is
  enabled.

Default value: 'rsyslog'

## Defined types

### logrotate::rule

Add a LogRotate Configuration

If options have a 'no' variant, then the no variant will be set if you set
the primary value to false

The ``logrotate(5)`` man page should be referenced for any undocumented
parameter.

* **See also**
logrotate(5)

#### Parameters

The following parameters are available in the `logrotate::rule` defined type.

##### `name`

Data type: `String`

Directly translates to the name of the file

##### `log_files`

Data type: `Array[String[1]]`

The log file strings for all logs to be affected by this stanza

##### `compress`

Data type: `Optional[Boolean]`

If undefined it defaults to the setting in logrotate.

Default value: `undef`

##### `compresscmd`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `uncompresscmd`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `compressext`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `compressoptions`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `copy`

Data type: `Boolean`



Default value: `false`

##### `copytruncate`

Data type: `Boolean`



Default value: `false`

##### `create`

Data type: `Pattern['\d{4} .+ .+']`



Default value: '0640 root root'

##### `rotate_period`

Data type: `Optional[Logrotate::Periods]`



Default value: `undef`

##### `dateext`

Data type: `Optional[Boolean]`

If set to true log files will be rotated using a date extension.
If false nodateext is set and rotated logs use a number extension.
If undefined it defaults to the setting in logrotate

Default value: `undef`

##### `dateformat`

Data type: `String[1]`



Default value: '-%Y%m%d.%s'

##### `dateyesterday`

Data type: `Optional[Boolean]`



Default value: `undef`

##### `delaycompress`

Data type: `Optional[Boolean]`



Default value: `undef`

##### `extension`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `ifempty`

Data type: `Boolean`



Default value: `false`

##### `ext_include`

Data type: `Optional[Array[String[1]]]`

Corresponds to the ``include`` logrotate configuration since it is a
reserved word in Puppet

Default value: `undef`

##### `mail`

Data type: `Optional[Simplib::EmailAddress]`



Default value: `undef`

##### `maillast`

Data type: `Boolean`

If false, mailfirst will be set. Ignored if $mail is `false`

Default value: `true`

##### `maxage`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### `maxsize`

Data type: `Optional[Logrotate::Size]`



Default value: `undef`

##### `minsize`

Data type: `Optional[Logrotate::Size]`



Default value: `undef`

##### `missingok`

Data type: `Boolean`



Default value: `false`

##### `olddir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: `undef`

##### `postrotate`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `prerotate`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `firstaction`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `lastaction`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `lastaction_restart_logger`

Data type: `Boolean`

Restart ``$logger_service`` as a logrotate ``lastaction``

* Has no effect if ``$lastaction`` is set

Default value: `false`

##### `logger_service`

Data type: `Optional[String[1]]`

The name of the service which will be restarted as a logrotate ``lastaction``

* NOTE: This will default to ``rsyslog`` unless otherwise specified either
  in the call to the define or as ``logrotate::logger_service``

Default value: simplib::lookup('logrotate::logger_service', {'default_value' => 'rsyslog'})

##### `rotate`

Data type: `Optional[Integer[0]]`

The number of old log files to keep.
If undefined it defaults to the setting in logrotate

Default value: `undef`

##### `size`

Data type: `Optional[Logrotate::Size]`



Default value: `undef`

##### `sharedscripts`

Data type: `Boolean`



Default value: `true`

##### `shred`

Data type: `Optional[Boolean]`



Default value: `undef`

##### `shredcycles`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### `start`

Data type: `Integer[0]`



Default value: 1

##### `su`

Data type: `Boolean`

Rotate logs as a different user and group. $su_user and $su_group are
required if this is set to true. Ignored on EL6.

Default value: `false`

##### `su_user`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `su_group`

Data type: `Optional[String[1]]`



Default value: `undef`

##### `tabooext`

Data type: `Optional[Array[String[1]]]`



Default value: `undef`

## Data types

### Logrotate::Periods

Allowed time intervals for logrotate

Alias of `Enum['hourly', 'daily', 'weekly', 'monthly', 'yearly']`

### Logrotate::Size

Size of a log in bytes, kilobytes, megabytes or gigabytes

Alias of `Variant[Integer[1], Pattern[/^[0-9]+[kMG]?$/]]`

