# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`nsswitch`](#nsswitch): Manages the system nsswitch.conf configuration
* [`nsswitch::params`](#nsswitchparams): nsswitch::params class
Provides default values for the nsswitch module according to the
operatingsystem being used.

## Classes

### nsswitch

This module creates a `nsswitch.conf` file with all the lines that determine
the sources from which to obtain name-service information in a range of
categories, and in what order.

* **See also**
nsswitch.conf(5)

#### Examples

##### Basic example

```puppet
include nsswitch

class { 'nsswitch':
  passwd => ['ldap','files'],
  hosts  => ['dns [!UNAVAIL=return]','files'],
}
```

#### Parameters

The following parameters are available in the `nsswitch` class.

##### `aliases`

Data type: `Optional[Variant[String, Array]]`

Mail aliases, used by getaliasent() and related functions.

Default value: $nsswitch::params::aliases_default

##### `automount`

Data type: `Optional[Variant[String, Array]]`

Which conventions to use for automounting of homes.

Default value: $nsswitch::params::automount_default

##### `bootparams`

Data type: `Optional[Variant[String, Array]]`

Where bootparams shall be supplied from (e.g. for diskless clients at boot
time using rpc.bootparamd).

Default value: $nsswitch::params::bootparams_default

##### `ethers`

Data type: `Optional[Variant[String, Array]]`

Ethernet numbers.

Default value: $nsswitch::params::ethers_default

##### `file_group`

Data type: `Optional[Variant[String]]`

Group of the nsswitch.conf file

Default value: $nsswitch::params::file_group

##### `file_owner`

Data type: `Variant[String]`

Owner of the nsswitch.conf file

Default value: 'root'

##### `file_perms`

Data type: `Variant[String]`

Permissions for the nsswitch.conf file

Default value: '0644'

##### `group`

Data type: `Optional[Variant[String, Array]]`

Groups of users, used by getgrent() and related functions.

Default value: $nsswitch::params::group_default

##### `gshadow`

Data type: `Optional[Variant[String, Array]]`

Shadow groups, used by getspnam() and related functions.

Default value: $nsswitch::params::gshadow_default

##### `hosts`

Data type: `Optional[Variant[String, Array]]`

Host names and numbers, used by gethostbyname() and related functions.

Default value: $nsswitch::params::hosts_default

##### `netgroup`

Data type: `Optional[Variant[String, Array]]`

Network-wide list of hosts and users, used for access rules.

Default value: $nsswitch::params::netgroup_default

##### `netmasks`

Data type: `Optional[Variant[String, Array]]`

Netmasks specify how much of the address to reserve for sub-dividing
networks into subnetworks.

Default value: $nsswitch::params::netmasks_default

##### `networks`

Data type: `Optional[Variant[String, Array]]`

Network names and numbers, used by getnetent() and related functions.

Default value: $nsswitch::params::networks_default

##### `passwd`

Data type: `Optional[Variant[String, Array]]`

User passwords, used by getpwent() and related functions.

Default value: $nsswitch::params::passwd_default

##### `protocols`

Data type: `Optional[Variant[String, Array]]`

Network protocols, used by getprotoent() and related functions.

Default value: $nsswitch::params::protocols_default

##### `publickey`

Data type: `Optional[Variant[String, Array]]`

Public and secret keys for Secure_RPC used by NFS and NIS+.

Default value: $nsswitch::params::publickey_default

##### `rpc`

Data type: `Optional[Variant[String, Array]]`

Remote procedure call names and numbers, used by getrpcbyname() and related
functions.

Default value: $nsswitch::params::rpc_default

##### `services`

Data type: `Optional[Variant[String, Array]]`

Network services, used by getservent() and related functions.

Default value: $nsswitch::params::services_default

##### `shadow`

Data type: `Optional[Variant[String, Array]]`

Shadow user passwords, used by getspnam() and related functions.

Default value: $nsswitch::params::shadow_default

##### `shells`

Data type: `Optional[Variant[String, Array]]`

Valid user shells, used by getusershell() and related functions.

Default value: $nsswitch::params::shells_default

##### `sudoers`

Data type: `Optional[Variant[String, Array]]`

Sudoers policy module users.

Default value: $nsswitch::params::sudoers_default

##### `file_path`

Data type: `Stdlib::Unixpath`

The path to `nsswitch.conf` on the system.

Default value: '/etc/nsswitch.conf'

### nsswitch::params

nsswitch::params class
Provides default values for the nsswitch module according to the
operatingsystem being used.

