# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`oath`](#oath): This module is utilized by other modules in SIMP to download TOTP required packages and configure them with sane defaults as to make pam_oath

_Private Classes_

* `oath::config`: This class is called from oath for pam_oath configuration. This class ensures files and directories have the correct selinux contexts to run 
* `oath::install`: This class is called from oath for installation of packages required to implement one-time passwords as part of PAM authentication.
* `oath::oathtool_install`: This class is called from oath for installation of the oathtool utility. This utility enables conversion of a secret key into an appropriate 

**Defined types**

* [`oath::config::exclude_group`](#oathconfigexclude_group): This define takes params and constructs a consistantly formated concat fragment that will be inserted as a line in /etc/liboath/exclude_group
* [`oath::config::exclude_user`](#oathconfigexclude_user): This define takes params and constructs a consistantly formated concat fragment that will be inserted as a line in /etc/liboath/exclude_users
* [`oath::config::user`](#oathconfiguser): This define takes params and constructs a consistantly formated concat fragment that will be inserted as a line in /etc/liboath/users.oath

## Classes

### oath

This module is utilized by other modules in SIMP to download TOTP required
packages and configure them with sane defaults as to make pam_oath.so a
functional pam module if used.

Example hieradata

  oath::oath_users:
    defaults:
      token_type: 'HOTP/T30/6'
      pin: '-'
    user:
      secret_key: 'my_secret_key'
    other_user:
      pin: '1234' # fields in user with override defaults
      secret_key: 'secret_key_for_other_user'

#### Parameters

The following parameters are available in the `oath` class.

##### `oath`

Data type: `Boolean`

Whether or not to install pam_oath and liboath (if true) or just oathtool
(a command-line utility for getting a 2FA code from a corresponding secret
key.

* Defaults to the global catalyst `simp_options::oath`.

Default value: simplib::lookup('simp_options::oath', { 'default_value' => false })

##### `pam`

Data type: `Boolean`

Whether or not pam is configured on the simp system.

* Will not install pam_oath without `$pam` being `true`.

**WARNING** If this is overriden to true, pam will install as a dependency
of pam_oath

Default value: simplib::lookup('simp_options::pam', { 'default_value' => true })

##### `package_ensure`

Data type: `Simplib::PackageEnsure`

Sets the value for resource => package, key => ensure.

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'present'})

##### `oath_exclude_users`

Data type: `Optional[Array]`

Optional array that will enter each array member as a user in the
exclude_users.oath file, keeping them from needing oath 2FA when configured
for other users.

Default value: `undef`

##### `oath_exclude_groups`

Data type: `Optional[Array]`

Optional array that will enter each array member as a group in the
exclude_groups.oath file, keeping members of these groups from needing
oath 2FA when configured for other users.

Default value: `undef`

##### `oath_users`

Data type: `Optional[Hash]`

`Hash` of users processed to create the users.oath file required by the
pam_oath.so module.

Defaults to hieradata in data/common.yaml. If this is deleted, or set to
undef, puppet will not manage users.oath. Processing happens in
manifests/config.pp with the config define being in
manifests/config/user.pp

Default value: `undef`

## Defined types

### oath::config::exclude_group

This define takes params and constructs a consistantly formated concat
fragment that will be inserted as a line in /etc/liboath/exclude_groups.oath

#### Parameters

The following parameters are available in the `oath::config::exclude_group` defined type.

##### `group`

Data type: `Pattern[/^[a-zA-Z0-9\-_]+(\s+)?$/]`

The group that will be affected

### oath::config::exclude_user

This define takes params and constructs a consistantly formated concat
fragment that will be inserted as a line in /etc/liboath/exclude_users.oath

#### Parameters

The following parameters are available in the `oath::config::exclude_user` defined type.

##### `user`

Data type: `Pattern[/^[a-zA-Z0-9\-_]+(\s+)?$/]`

The username that will be affected

### oath::config::user

This define takes params and constructs a consistantly formated concat
fragment that will be inserted as a line in /etc/liboath/users.oath

#### Parameters

The following parameters are available in the `oath::config::user` defined type.

##### `user`

Data type: `Array[String[1]]`

The username that will be affected

##### `token_type`

Data type: `Pattern[/^HOTP((\/T\d+)?(\/\d+)?)(\s+)?$/]`

The type of OATH token that you are managing:

* Valid Options:
  * `HOTP`
  * `HOTP/T<window_time>`
  * `HOTP/<one-time_password_length>`
  * `HOTP/T<window_time>/<one-time_password_length>`

##### `pin`

Data type: `Variant[Enum['-','+'], Integer[0,99999999]]`

The PIN to use for the OATH token

##### `secret_key`

Data type: `Pattern[/^(..)+(\s+)?$/]`

Any continuous string of even length (odd length can break secret_key to
one-time password generators)

