# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`openscap`](#openscap): This class installs SCAP content and the associated tools. It is mostly based on the scap-security-guide open source project with several cus
* [`openscap::schedule`](#openscapschedule): This class allows you to set a schedule for openscap to run a check on your system via cron.

**Data types**

* [`Openscap::Profile`](#openscapprofile): Valid OpenSCAP profile names

## Classes

### openscap

This class installs SCAP content and the associated tools.
It is mostly based on the scap-security-guide open source project
with several customizations for SIMP.

#### Parameters

The following parameters are available in the `openscap` class.

##### `enable_schedule`

Data type: `Boolean`

Run an OpenSCAP scan on a schedule, using `openscap::schedule`

Default value: `false`

##### `scap_ensure`

Data type: `String`

Package ensure value for the `openscap-utils` package

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })

##### `ssg_ensure`

Data type: `String`

Package ensure value for the `scap-security-guide` package

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })

### openscap::schedule

This class allows you to set a schedule for openscap to run a check
on your system via cron.

#### Parameters

The following parameters are available in the `openscap::schedule` class.

##### `scap_profile`

Data type: `Openscap::Profile`

The name of the profile with the content.

* Valid profiles change based on the target system. See the results of the
`oscap` fact for valid targets.

##### `oscap_path`

Data type: `Stdlib::Absolutepath`

The path to the `oscap` executable

* This is set to a sane default for most systems but will pick the value
   out of the `oscap` fact if it has been installed and is in the path.

Default value: pick(fact('oscap.path'), '/bin/oscap')

##### `ssg_base_dir`

Data type: `Stdlib::Absolutepath`

The starting directory for all SSG content. Change this if you want to
install your own SSG profiles.

Default value: '/usr/share/xml/scap/ssg/content'

##### `ssg_data_stream`

Data type: `Pattern[/^.+\.xml$/]`

Type: XML file under $ssg_base_dir
The data stream XML file to use for your system scan. This must be a file
under $ssg_base_dir.

##### `fetch_remote_resources`

Data type: `Boolean`

If true, download remote content referenced by XCCDF.

Default value: `false`

##### `scap_tailoring_file`

Data type: `Optional[Stdlib::Absolutepath]`

Use  given  file  for XCCDF tailoring.

Default value: `undef`

##### `logdir`

Data type: `Stdlib::Absolutepath`

Specifies output location.  Default is /var/log/openscap

Default value: '/var/log/openscap'

##### `logrotate`

Data type: `Boolean`

If true, use logrotate to rotate the output logs.

Default value: simplib::lookup('simp_options::logrotate', { 'default_value' => false})

##### `minute`

Data type: `Simplib::Cron::Minute`



Default value: 30

##### `hour`

Data type: `Simplib::Cron::Hour`



Default value: 1

##### `monthday`

Data type: `Simplib::Cron::MonthDay`



Default value: '*'

##### `month`

Data type: `Simplib::Cron::Month`



Default value: '*'

##### `weekday`

Data type: `Simplib::Cron::Weekday`



Default value: 1

##### `force`

Data type: `Boolean`

If set, ignore the fact that `oscap` does not appear to be installed on the
target system and add the schedule anyway

* This should be used if you've installed `oscap` into a non-standard
  location that cannot be found by the fact in the default path

Default value: `false`

## Data types

### Openscap::Profile

Valid OpenSCAP profile names

Alias of `Pattern[/xccdf_[^_]+_profile_.+/]`

