# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`resolv`](#resolv): Configure resolv.conf  See resolv.conf(5) for details on the various options.
* [`resolv::host_conf`](#resolvhost_conf): This class configures /etc/host.conf. See host.conf(5) for descriptions of the variables.

**Data types**

* [`Resolv::Domain`](#resolvdomain): Valid values for the resolv.conf "domain" option
* [`Resolv::Sortlist`](#resolvsortlist): Valid resolv.conf `sortlist` field

## Classes

### resolv

Configure resolv.conf

See resolv.conf(5) for details on the various options.

#### Parameters

The following parameters are available in the `resolv` class.

##### `servers`

Data type: `Array[Simplib::IP,0,3]`

An array of servers to query. If the first server is '127.0.0.1' or '::1'
then the host will be set up as a caching DNS server unless $caching is
set to false.  The other hosts will be used as the higher level
nameservers

Default value: simplib::lookup('simp_options::dns::servers', { 'default_value' => ['127.0.0.1'] })

##### `search`

Data type: `Array[Simplib::Domain,0,6]`

Array of entries that will be searched, in order, for hosts.

Default value: simplib::lookup('simp_options::dns::search', { 'default_value'  => [$facts['domain']] })

##### `resolv_domain`

Data type: `Resolv::Domain`

Local domain name, defaults to the domain of your host.

Default value: $facts['domain']

##### `debug`

Data type: `Boolean`

Print debugging messages

Default value: `false`

##### `rotate`

Data type: `Boolean`

When `true`, enables round-robin selection of $servers to distribute the
query load.

Default value: `true`

##### `no_check_names`

Data type: `Boolean`

When `true`, disables the modern BIND checking of incoming hostnames and
mail names for invalid characters such as underscore (`_`), non-ASCII, or
control characters.

Default value: `false`

##### `inet6`

Data type: `Boolean`

When `true`, use AAAA (IPv6) queries and convert A (IPv4) results

Default value: `false`

##### `ndots`

Data type: `Integer[0,15]`

Value for the `ndots:` option in resolv.conf

Default value: 1

##### `timeout`

Data type: `Integer[0,30]`

Amount of time (in seconds) the resolver will wait for a response

Default value: 2

##### `attempts`

Data type: `Integer[0,5]`

Number of times to attempt querying $servers before giving up

Default value: 2

##### `named_server`

Data type: `Boolean`

A boolean that states that this server is definitively a named server.
Bypasses the need for $named_autoconf below.

Default value: `false`

##### `named_autoconf`

Data type: `Boolean`

A boolean that controlls whether or not to autoconfigure named.
true => If the server where puppet is being run is in the list of
        $servers then automatically configure named.
false => Do not autoconfigure named.

Default value: `true`

##### `caching`

Data type: `Boolean`

*If* the $servers array above starts with '127.0.0.1' or '::1', then
the system will set itself up as a caching nameserver unless this is set
to false.

Default value: `true`

##### `use_nmcli`

Data type: `Boolean`

Specify if the $servers should be applied via nmcli in addition to being
managed via resolv.conf

Default value: `false`

##### `nmcli_connection_name`

Data type: `Optional[String]`

If managing DNS servers via nmcli, this is the connection the IPv4 DNS
servers will be added to

Default value: `undef`

##### `nmcli_ignore_auto_dns`

Data type: `Boolean`

A boolean that toggles the ignore_auto_dns flag for nmcli

true => ignore the automatic DNS entries from Network Manager and instead
only use servers explicitly passed to this manifest
false => include the DNS entries from Network Manager

Default value: `true`

##### `nmcli_auto_reapply_device`

Data type: `Boolean`

A boolean to toggle automatic device reapplies for affected Network Manager
device

true => trigger a device reapply on the device that had DNS servers added
to it
false => do not trigger any device reapply

Default value: `false`

##### `sortlist`

Data type: `Optional[Resolv::Sortlist]`

Optional Array of address/netmask pairs that allow addresses returned by
gethostbyname to be sorted.

Default value: `undef`

##### `extra_options`

Data type: `Optional[Array[String]]`

Optional Array to put any options that may not be covered by the variables
below. These will be appended to the options string.

Default value: `undef`

### resolv::host_conf

This class configures /etc/host.conf.
See host.conf(5) for descriptions of the variables.

#### Parameters

The following parameters are available in the `resolv::host_conf` class.

##### `trim`

Data type: `Optional[Array[Pattern[/^\./]]]`



Default value: `undef`

##### `multi`

Data type: `Boolean`



Default value: `true`

##### `spoof`

Data type: `Optional[String]`

defunct, see: https://bugzilla.redhat.com/show_bug.cgi?id=1577265)

Remains to prevent issues with direct ``class`` calls.

Default value: `undef`

##### `reorder`

Data type: `Boolean`



Default value: `true`

## Data types

### Resolv::Domain

Valid values for the resolv.conf "domain" option

Alias of `Variant[Simplib::Domain, Enum['.']]`

### Resolv::Sortlist

Valid resolv.conf `sortlist` field

Alias of `Array[Variant[Simplib::IP,Simplib::IP::V4::DDQ,Simplib::IP::V6], 0, 10]`

