# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`selinux`](#selinux)
* [`selinux::config`](#selinuxconfig): Set global SELinux system parameters
* [`selinux::install`](#selinuxinstall): Install selinux-related packages not managed by vox_selinux
* [`selinux::service`](#selinuxservice): Ensures mcstrans and restorecond services managed

### Resource types

* [`selinux_login`](#selinux_login): Manage SELinux login mapping configuration  NOTE: You may need to run `restorecon -RF` on any user home directories that have their default c
* [`selinux_state`](#selinux_state): Toggle the enforcement of selinux

### Data types

* [`Selinux::State`](#selinuxstate): Types of selinux enforcement

## Classes

### `selinux`

The selinux class.

#### Parameters

The following parameters are available in the `selinux` class.

##### `package_ensure`

Data type: `String`

The ensure status of packages to be installed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### `login_resources`

Data type: `Optional[Hash]`

A hash of resources that should be created on the system as expected by
`create_resources()` called on the `selinux_login` type

A deep merge strategy is used when performing APL lookups on this value by
default.

@example Change __default__ to user_u
  ---
  selinux::login_resources:
    "__default__":
      seuser: user_u
      mls_range: s0
    "%admins":
      seuser: staff_u
      # This only works if you enable mcstransd
      # using selinux::manage_mcstrans_service: true
      mls_range: "SystemLow-SystemHigh"

Default value: ``undef``

##### `manage_mcstrans_package`

Data type: `Boolean`



##### `manage_mcstrans_service`

Data type: `Boolean`



##### `mcstrans_package_name`

Data type: `String`



##### `mcstrans_service_name`

Data type: `String`



##### `manage_restorecond_package`

Data type: `Boolean`



##### `manage_restorecond_service`

Data type: `Boolean`



##### `restorecond_package_name`

Data type: `String`



##### `ensure`

Data type: `Selinux::State`



Default value: `'enforcing'`

##### `kernel_enforce`

Data type: `Boolean`



Default value: ``false``

##### `autorelabel`

Data type: `Boolean`



Default value: ``false``

##### `manage_utils_package`

Data type: `Boolean`



Default value: ``true``

##### `mode`

Data type: `Enum['targeted','mls']`



Default value: `'targeted'`

### `selinux::config`

Set global SELinux system parameters

### `selinux::install`

Install selinux-related packages not managed by vox_selinux

### `selinux::service`

Ensures mcstrans and restorecond services managed

## Resource types

### `selinux_login`

Manage SELinux login mapping configuration

NOTE: You may need to run `restorecon -RF` on any user home directories that
have their default contexts updated. This is particularly important for the
`__default__` login entry but cannot be automated given the potential load
and unintended system consequences.

#### Properties

The following properties are available in the `selinux_login` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `mls_range`

Valid values: `/^.+$/`

The Multi-Level Security range to be applied to the login

##### `seuser`

Valid values: `/^.+$/`

The SELinux user to which the login should be mapped.
You can get a list by running `semanage user -l`

#### Parameters

The following parameters are available in the `selinux_login` type.

##### `force`

Valid values: ``true``, ``false``, `yes`, `no`

Force the modification of potentially unsafe logins such as "root" and "__default__"

Default value: ``false``

##### `name`

namevar

The user or group name to be managed. Groups must be prefixed with a "%"

##### `provider`

The specific backend to use for this `selinux_login` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### `selinux_state`

Toggle the enforcement of selinux

#### Properties

The following properties are available in the `selinux_state` type.

##### `ensure`

Valid values: ``false``, ``true``, `disabled`, `permissive`, `enforcing`

Set the SELinux state on the system

Default value: `enforcing`

#### Parameters

The following parameters are available in the `selinux_state` type.

##### `autorelabel`

Valid values: ``true``, ``false``, `yes`, `no`

Automatically determine if the filesystem needs to be relabeled.
  Enforcing > Permissive > Disabled
Going to the right requires relabeling.

Default value: ``true``

##### `name`

namevar

An arbitrary, but unique, name for the resource.

##### `provider`

The specific backend to use for this `selinux_state` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Data types

### `Selinux::State`

Types of selinux enforcement

Alias of `Variant[Boolean, Enum[
    'enforcing',
    'permissive',
    'disabled'
  ]]`

