# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`simp_bolt`](#simp_bolt): Installs and configures Puppet Bolt for use within the SIMP environment
* [`simp_bolt::controller`](#simp_boltcontroller): Installs and configures Puppet Bolt for use within the SIMP enviroment
* [`simp_bolt::controller::config`](#simp_boltcontrollerconfig): Set the global configuration and transport options for Bolt.
* [`simp_bolt::controller::install`](#simp_boltcontrollerinstall): This class is called from simp_bolt for install.
* [`simp_bolt::target`](#simp_bolttarget): Configure a system to be managed by Puppet Bolt
* [`simp_bolt::target::user`](#simp_bolttargetuser): Configure a 'simp_bolt' system user and login capabilities

**Data types**

* [`Simp_bolt::LogLevel`](#simp_boltloglevel): Bolt Log Levels
* [`Simp_bolt::Transport`](#simp_bolttransport): Bolt Transports

## Classes

### simp_bolt

This class will not do anything on the target system by default. You must
opt-in to adding either the controller or the target configuration.

#### Parameters

The following parameters are available in the `simp_bolt` class.

##### `target_user_name`

Data type: `String[1]`

The username of the account to use on target systems

Default value: 'simp_bolt'

##### `target_user_home`

Data type: `Stdlib::Unixpath`

The full path to the user's home directory on target systems

Default value: "/var/local/${target_user_name}"

##### `target_sudo_user`

Data type: `Optional[String[1]]`

The user that the ``username`` user may escalate to on target systems

Default value: 'root'

##### `bolt_controller`

Data type: `Boolean`

Install and configure Puppet Bolt.

* Configuration specifics should be managed via the
  ``simp_bolt::controller`` parameters.

Default value: `false`

##### `bolt_target`

Data type: `Boolean`

Configure the system as a target for Bolt management

* Configuration specifics should be managed via the
  ``simp_bolt::target`` parameters.

Default value: `false`

##### `package_name`

Data type: `String`

The name of the Puppet Bolt rpm package

Default value: 'puppet-bolt'

### simp_bolt::controller

Installs and configures Puppet Bolt for use within the SIMP enviroment

#### Parameters

The following parameters are available in the `simp_bolt::controller` class.

##### `local_user_name`

Data type: `Optional[String[1]]`

The username of the local user account to launch bolt commands

* NOTE: Ensure that this user is local to the host since Puppet will be
  managing files in the user's home directory.

Default value: `undef`

##### `local_group_name`

Data type: `Optional[String[1]]`

The default group name of the local user account

Default value: $local_user_name

##### `local_user_home`

Data type: `Optional[Stdlib::Unixpath]`

The full path to the local user's home directory

Default value: `undef`

### simp_bolt::controller::config

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

Addtional details on the options can be found at
https://puppet.com/docs/bolt/latest/bolt_configuration_options.html.

#### Parameters

The following parameters are available in the `simp_bolt::controller::config` class.

##### `local_user`

Data type: `Optional[String[1]]`

The local account to be used for running Bolt. The default is the $username account specified
in the user.pp manifest.

Default value: getvar(simp_bolt::controller::local_user_name)

##### `local_group`

Data type: `Optional[String[1]]`

The local group to be used for file permissions associated with the local_user account. The
default is the $username account specified in the user.pp manifest.

Default value: getvar(simp_bolt::controller::local_group_name)

##### `local_home`

Data type: `Stdlib::Unixpath`

The home directory of the local account to be used for running Bolt. The default is the
$home directory for the account specified in the user.pp manifest.

Default value: pick(getvar(simp_bolt::controller::local_user_home), '/var/local/simp_bolt')

##### `config_hash`

Data type: `Optional[Hash]`

If specified, will be passed to the ``to_yaml`` function and output at the
entire configuation of the ``bolt.yaml`` configuation file.

* No further options will be honored if this is specified

Default value: `undef`

##### `color`

Data type: `Boolean`

Whether to use colored output when printing messages to the console. By default, in Bolt,
this is true.

Default value: `true`

##### `concurrency`

Data type: `Optional[Integer[0]]`

The number of threads to use when executing on remote nodes. By default, in Bolt, this
is 100.

Default value: `undef`

##### `default_transport`

Data type: `Simp_bolt::Transport`

The default transport to use when not specified in the URL or inventory.

Default value: 'ssh'

##### `disable_analytics`

Data type: `Boolean`

Disable all vendor 'phone-home' mechanics in Bolt.

Default value: `true`

##### `format`

Data type: `Optional[Enum['human','json']]`

The format to use when printing results; either human or json. By default, in Bolt, this
is human.

Default value: `undef`

##### `hiera_config`

Data type: `Optional[String[1]]`

The path to the Hiera config file. By default, in Bolt, this is `hiera.yaml` in the Bolt
project directory at `~/.puppetlabs/bolt`.

Default value: `undef`

##### `inventoryfile`

Data type: `Optional[String[1]]`

Path to a structured data inventory file used to refer to groups of nodes on the command
line and from plans. By default, in Bolt, this is `inventory.yaml` in the Bolt project
directory at `~/.puppetlabs/bolt`.

Default value: `undef`

##### `log_console_level`

Data type: `Simp_bolt::LogLevel`

The type of information to display on the console. Valid options are debug, info, notice,
warn, and error. The default is info.

Default value: 'info'

##### `log_file`

Data type: `Stdlib::Unixpath`

The path and name of the log file.

Default value: '/var/log/puppetlabs/bolt/bolt.log'

##### `log_file_level`

Data type: `Simp_bolt::LogLevel`

The type of information to record in the log file. Valid options are debug, info, notice,
warn, and error. By default in Bolt this is info.

Default value: 'info'

##### `log_file_append`

Data type: `Boolean`

Add output to an existing log file. By default in Bolt this is true.

Default value: `true`

##### `modulepath`

Data type: `Optional[String[1]]`

The module path for loading tasks and plan code, formatted as a string containing a list
of directories. The first directory listed will be the default for downloaded modules.
By default, in Bolt, this is "modules:site-modules:site" within the Bolt project directory
in `~/.puppetlabs/bolt`.

Default value: `undef`

##### `tty`

Data type: `Boolean`

Request a pseudo TTY on nodes that support it. By default in Bolt this is false.

Default value: `true`

##### `transport_options`

Data type: `Hash[Simp_bolt::Transport, Hash]`

A Hash of transport options that will be added to the configuration file
without any error checking of key/value pairs.

You must have settings specified for the ``$default_transport``

Default value: {
                                                              'ssh' => {
                                                                'tmpdir' => $simp_bolt::target_user_home,
                                                                'user'   => $simp_bolt::target_user_name,
                                                                'run-as' => getvar(simp_bolt::target_sudo_user),
                                                                'tty'    => $tty
                                                              }.delete_undef_values
                                                            }

### simp_bolt::controller::install

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

### simp_bolt::target

Configure a system to be managed by Puppet Bolt

#### Parameters

The following parameters are available in the `simp_bolt::target` class.

##### `create_user`

Data type: `Boolean`

Create the user on the target system

Default value: `false`

##### `user_name`

Data type: `String[1]`

The username to use for remote access

* Has no effect if ``$create_user`` is ``false``

Default value: $simp_bolt::target_user_name

##### `disallowed_users`

Data type: `Array[String[1]]`

Users that may not be used for the remote ``bolt`` login user

Default value: ['root']

##### `user_password`

Data type: `Optional[String[8]]`

The password for the user in passwd-compatible salted hash form

* Has no effect if ``$create_user`` is ``false``

Default value: `undef`

##### `user_home`

Data type: `Stdlib::Unixpath`

The full path to the user's home directory

* Has no effect if ``$create_user`` is ``false``

Default value: $simp_bolt::target_user_home

##### `user_uid`

Data type: `Integer[500]`

The UID of the user

* Has no effect if ``$create_user`` is ``false``

Default value: 1779

##### `user_gid`

Data type: `Integer[500]`

The GID of the user

* Has no effect if ``$create_user`` is ``false``

Default value: $user_uid

##### `user_ssh_authorized_keys`

Data type: `Optional[Array[String[1]]]`

The SSH public key for authorized Bolt users

* See the native ``ssh_authorized_key`` resource definition for details

Default value: `undef`

##### `user_ssh_authorized_key_type`

Data type: `String[1]`

The SSH public key type

* See the native ``ssh_authorized_key`` resource definition for details

Default value: 'ssh-rsa'

##### `user_sudo_user`

Data type: `Optional[String[1]]`

The user that the ``username`` user may escalate to

If set to ``undef``, will not manage sudo settings on the target system for
this user.

Default value: getvar(simp_bolt::target_sudo_user)

##### `user_sudo_password_required`

Data type: `Boolean`

Require password for user to sudo

Default value: `false`

##### `user_sudo_commands`

Data type: `Array[String[1],1]`

The commands that the ``username`` user is allowed to execute via sudo as one
of the allowed users

Default value: ['ALL']

##### `user_allowed_from`

Data type: `Array[String[1]]`

The ``pam_access`` compatible locations that the user will be logging in
from

* Set to ``['ALL']`` to allow from any location
* If empty, will disable the use of pam_access for this user

Default value: [pick(fact('puppet_server'), 'LOCAL')]

##### `user_max_logins`

Data type: `Optional[Integer[1]]`

The ``pam_limits`` restricting the number of concurrent sessions permitted for
``username``

If set to ``undef``, will not restrict the maximum number of logins for the
user

Default value: 2

### simp_bolt::target::user

NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

#### Parameters

The following parameters are available in the `simp_bolt::target::user` class.

##### `create`

Data type: `Boolean`

Create the user on the target system

Default value: $simp_bolt::target::create_user

##### `username`

Data type: `String`

The username to use for remote access

Default value: $simp_bolt::target::user_name

##### `password`

Data type: `Optional[String[8]]`

The password for the user in passwd-compatible salted hash form

Default value: getvar(simp_bolt::target::user_password)

##### `home`

Data type: `Stdlib::Unixpath`

The full path to the user's home directory

Default value: $simp_bolt::target::user_home

##### `uid`

Data type: `Integer`

The UID of the user

Default value: $simp_bolt::target::user_uid

##### `gid`

Data type: `Integer`

The GID of the user

Default value: $simp_bolt::target::user_gid

##### `ssh_authorized_keys`

Data type: `Optional[Array[String[1]]]`

The SSH public key for the user

* See the native ``ssh_authorized_key`` resource definition for details

Default value: getvar(simp_bolt::target::user_ssh_authorized_keys)

##### `ssh_authorized_key_type`

Data type: `String[1]`

The SSH public key type

* See the native ``ssh_authorized_key`` resource definition for details

Default value: $simp_bolt::target::user_ssh_authorized_key_type

##### `sudo_user`

Data type: `Optional[String[1]]`

The users that the ``username`` user may escalate to

Default value: getvar(simp_bolt::target::user_sudo_user)

##### `sudo_password_required`

Data type: `Boolean`

Require password for user to sudo

Default value: $simp_bolt::target::user_sudo_password_required

##### `sudo_commands`

Data type: `Array[String[1]]`

The commands that the ``username`` user is allowed to execute via sudo as one
of the allowed users

Default value: $simp_bolt::target::user_sudo_commands

##### `allowed_from`

Data type: `Array[String[1]]`

The ``pam_access`` compatible locations that the user will be logging in
from

* Set to ``['ALL']`` to allow from any location

Default value: $simp_bolt::target::user_allowed_from

##### `max_logins`

Data type: `Optional[Integer[1]]`

The ``pam_limits`` restricting the number of concurrent sessions permitted for
``username``

Default value: getvar(simp_bolt::target::user_max_logins)

## Data types

### Simp_bolt::LogLevel

Bolt Log Levels

Alias of `Enum['debug', 'info', 'notice', 'warn', 'error']`

### Simp_bolt::Transport

Bolt Transports

Alias of `Enum['docker', 'local', 'pcp', 'ssh', 'winrm']`

