# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`simp_nfs`](#simp_nfs): A SIMP Profile for common NFS configurations
* [`simp_nfs::create_home_dirs`](#simp_nfscreate_home_dirs): Adds a script to create user home directories for directory server
* [`simp_nfs::export::home`](#simp_nfsexporthome): Configures an NFS server to share centralized home directories via NFSv4
* [`simp_nfs::mount::home`](#simp_nfsmounthome): Set up an ``NFS4`` client to point to mount your remote home directories

## Classes

### `simp_nfs`

A SIMP Profile for common NFS configurations

#### Parameters

The following parameters are available in the `simp_nfs` class.

##### `export_home_dirs`

Data type: `Boolean`

Set up home directory exports for this system

* The ``simp_options::trusted_nets`` parameter will govern what clients may
  connect to the share by default.
* Further configuration for home directory exports can be tweaked via the
  parameters in ``simp_nfs::export_home``

Default value: ``false``

##### `home_dir_server`

Data type: `Optional[Simplib::Ip]`

If set, specifies the server from which you want to mount NFS home
directories for your users

* If ``$export_home_dirs`` is also set, this class will assume that you
  want to mount on the local server if this is set at all
* Further configuration for the home directory mounts can be tweaked via
  the parameters in ``simp_nfs::mount::home``

Default value: ``undef``

##### `autodetect_remote`

Data type: `Boolean`

Use inbuilt autodetection to determine if the local system is the server
from which we should be mouting directories

* Generally, you should set this to ``false`` if you have issues with the
  system mounting to ``127.0.0.1`` when your home directories are actually
  on another system

Default value: ``true``

##### `use_autofs`

Data type: `Boolean`

Use ``autofs`` for home directory mounts

Default value: ``true``

### `simp_nfs::create_home_dirs`

by pulling users from LDAP

https://github.com/simp/pupmod-simp-simp_nfs/graphs/contributors

#### Parameters

The following parameters are available in the `simp_nfs::create_home_dirs` class.

##### `uri`

Data type: `Array[Simplib::URI]`

The uri(s) of the LDAP servers

Default value: `simplib::lookup('simp_options::ldap::uri')`

##### `base_dn`

Data type: `String`

The root DN that should be used when searching for entries

Default value: `simplib::lookup('simp_options::ldap::base_dn')`

##### `bind_dn`

Data type: `String`

The DN to use when binding to the LDAP server

Default value: `simplib::lookup('simp_options::ldap::bind_dn')`

##### `bind_pw`

Data type: `String`

The password to use when binding to the LDAP server

Default value: `simplib::lookup('simp_options::ldap::bind_pw')`

##### `export_dir`

Data type: `Stdlib::Absolutepath`

The location of the home directories being exported

* This location must be a puppet managed ``File`` resource
* See the ``simp_nfs::export_home`` class for an example

Default value: `'/var/nfs/home'`

##### `skel_dir`

Data type: `Stdlib::Absolutepath`

The location of sample skeleton files for user directories

Default value: `'/etc/skel'`

##### `ldap_scope`

Data type: `Enum['one','sub','base']`

The search scope to use

Default value: `'one'`

##### `port`

Data type: `Simplib::Port`

The target port on the LDAP server

* If none specified, defaults to ``389`` for regular and ``start_tls``
  connections, and ``636`` for legacy SSL connections

Default value: `389`

##### `tls`

Data type: `Enum['ssl','start_tls','none']`

Whether or not to enable SSL/TLS for the connection

* ``ssl``
    * ``LDAPS`` on port ``636`` unless  different ``port`` specified
        * Uses ``simple_tls``; No validation of the LDAP server's SSL
          certificate is performed

* ``start_tls``
    * Start TLS on port ``389`` unless different ``port`` specified

* ``none``
    * LDAP without encryption on port ``389`` unless different ``port``
      specified

Default value: `'start_tls'`

##### `quiet`

Data type: `Boolean`

Whether or not to print potentially useful warnings

Default value: ``true``

##### `syslog_facility`

Data type: `Simplib::Syslog::CFacility`

The syslog facility at which to log, must be Ruby ``syslog`` compatible

Default value: `'LOG_LOCAL6'`

##### `syslog_severity`

Data type: `Simplib::Syslog::CSeverity`

The syslog severity at which to log, must be Ruby ``syslog`` compatible

Default value: `'LOG_NOTICE'`

##### `strip_128_bit_ciphers`

Data type: `Boolean`

On EL6 systems, all 128-bit ciphers will be removed from ``tls_cipher_suite``

* This is due to a bug in the LDAP client libraries that does not appear to
  honor the order of the SSL ciphers and will attempt to connect with
  128-bit ciphers and not use stronger ciphers when those are present. This
  breaks connections to securely configured LDAP servers.

Default value: ``true``

##### `tls_cipher_suite`

Data type: `Array[String[1]]`

The TLS ciphers that should be used for the connection to LDAP

* Presently only affects EL6 systems

Default value: `simplib::lookup('simp_options::openssl::cipher_suite', { 'default_value' => ['DEFAULT','!MEDIUM'] })`

##### `package_ensure`

Data type: `String`

The ensure status of the rubygem-net-ldap package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### `simp_nfs::export::home`

Sets up the export root at ``${data_dir}/nfs/exports`` and then adds
``${data_dir}/nfs/home`` and submounts it under ``${data_dir}/nfs/exports``.

* The export root is the root NFS share directory for the NFSv4 pseudo
  filesystem. Each directory below that NFS share should be a bind mount
  to a directory on the NFS server.
* The exported home directory should be mounted as ``$nfs_server:/home`` from
  your clients, where ``$nfs_server`` is the IP address of the NFS server.

#### Examples

##### NFS Server System Hieradata

```puppet
---
nfs::is_server : true
simp::classes :
  - simp_nfs::export::home
```

##### NFS Client Home Mount

```puppet
---
simp_nfs::mount::home::nfs_server : <nfs_server_ip>
simp::classes :
  - simp_nfs::mount::home
```

#### Parameters

The following parameters are available in the `simp_nfs::export::home` class.

##### `data_dir`

Data type: `Stdlib::Absolutepath`



Default value: `'/var'`

##### `trusted_nets`

Data type: `Simplib::Netlist`

The networks that are allowed to mount this space

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

##### `sec`

Data type: `Array[Enum['none','sys','krb5','krb5i','krb5p']]`

An Array of sec modes for the export.

Default value: `['sys']`

##### `create_home_dirs`

Data type: `Boolean`

Automatically create user home directories from LDAP data

Default value: `simplib::lookup('simp_options::ldap', { 'default_value' => false })`

### `simp_nfs::mount::home`

If this system is also the NFS server, you need to set
``nfs::client::is_server`` to ``true`` or set
``simp_nfs::mount::home::nfs_server`` to ``127.0.0.1``.

#### Parameters

The following parameters are available in the `simp_nfs::mount::home` class.

##### `nfs_server`

Data type: `Simplib::IP`

The NFS server to which you will be connecting

* If you are the server, please make sure that this is ``127.0.0.1``

##### `remote_path`

Data type: `Stdlib::Absolutepath`

The NFS share that you want to mount

Default value: `'/home'`

##### `local_home`

Data type: `Stdlib::Absolutepath`

The local base for home directories

* Most sites will want this to be ``/home`` but some may opt for something
  like ``/exports/home`` or the like.

* Top level directories will **not** be automatically managed

Default value: `'/home'`

##### `port`

Data type: `Optional[Simplib::Port]`

The NFS port to which to connect

Default value: ``undef``

##### `sec`

Data type: `Enum['sys','krb5','krb5i','krb5p']`

The sec mode for the mount

* Only valid with NFSv4

Default value: `'sys'`

##### `options`

Data type: `Optional[String]`

The mount options string that should be used

* fstype and port will already be set for you

Default value: ``undef``

##### `at_boot`

Data type: `Boolean`

Ensure that this mount is mounted at boot time

* Has no effect if ``$use_autofs`` is set

Default value: ``true``

##### `autodetect_remote`

Data type: `Boolean`

Use inbuilt autodetection to determine if the local system is the server
from which we should be mouting directories

* Generally, you should set this to ``false`` if you have issues with the
  system mounting to ``127.0.0.1`` when your home directories are actually
  on another system

Default value: ``true``

##### `use_autofs`

Data type: `Boolean`

Enable automounting with Autofs

Default value: ``true``

