# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`simp_openldap`](#simp_openldap): This class provides a common base for both the client and server portions of an OpenLDAP-based sysetm
* [`simp_openldap::client`](#simp_openldapclient): Set up /etc/openldap/ldap.conf with the global options for accessing the LDAP servers.  Regarding: POODLE - CVE-2014-3566  The ``tls_cipher_s
* [`simp_openldap::server`](#simp_openldapserver): Set up an OpenLDAP server  It installs the server if not already installed and bootstraps it if necessary.  You can quickly reset the entire 
* [`simp_openldap::server::conf`](#simp_openldapserverconf): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  This class configures the brunt of the `
* [`simp_openldap::server::conf::default_ldif`](#simp_openldapserverconfdefault_ldif): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  This allows for the modification of the 
* [`simp_openldap::server::fix_bad_upgrade`](#simp_openldapserverfix_bad_upgrade): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  We're not ready for using slapd.d  Occas
* [`simp_openldap::server::install`](#simp_openldapserverinstall): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  Install the required packages
* [`simp_openldap::server::service`](#simp_openldapserverservice): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  Manage the OpenLDAP service
* [`simp_openldap::slapo::lastbind`](#simp_openldapslapolastbind): This class configures lastbind and set up a dynamic include that defines lastbind. See slapo-lastbind(5) for details of the options.
* [`simp_openldap::slapo::ppolicy`](#simp_openldapslapoppolicy): Configure the password policy for a site  This also includes the options for configuring the password checking plugin that's included with SI
* [`simp_openldap::slapo::syncprov`](#simp_openldapslaposyncprov): Allow other LDAP servers to synchronize with this one

### Defined types

* [`simp_openldap::server::access`](#simp_openldapserveraccess): Manage access control entries in ``slapd.access``  Remember that **order matters**! Entries will be listed in alphanumeric order after the ``
* [`simp_openldap::server::dynamic_include`](#simp_openldapserverdynamic_include): Add a dynamically included file into the LDAP system.
* [`simp_openldap::server::limits`](#simp_openldapserverlimits): This define allows you to manage ``limits`` sections under the **main** database
* [`simp_openldap::server::syncrepl`](#simp_openldapserversyncrepl): This define configures the sycnrepl functionality of OpenLDAP which allows for directory synchronization pulls from a master server.  $name s

### Data types

* [`Simp_Openldap::LogLevel`](#simp_openldaploglevel): OpenLDAP Log Levels
* [`Simp_Openldap::SlapdConf::Disallow`](#simp_openldapslapdconfdisallow): OpenLDAP slapd.conf disallow

## Classes

### `simp_openldap`

This class provides a common base for both the client and server portions of
an OpenLDAP-based sysetm

#### Parameters

The following parameters are available in the `simp_openldap` class.

##### `ldap_uri`

Data type: `Array[Simplib::URI]`

It is recommended that you make the master the last entry in this array

* Will default to ``["ldap://${server_facts['servername']}"]`` if not set

Default value: `simplib::lookup('simp_options::ldap::uri', { 'default_value' => undef })`

##### `base_dn`

Data type: `String`

The base DN of the LDAP entries

Default value: `simplib::lookup('simp_options::ldap::base_dn', { 'default_value' => simplib::ldap::domain_to_dn() })`

##### `bind_dn`

Data type: `String`

The use that should be used to bind to the LDAP server

Default value: `simplib::lookup('simp_options::ldap::bind_dn', { 'default_value' => sprintf('cn=hostAuth,ou=Hosts,%s', simplib::ldap::domain_to_dn()) })`

##### `ldap_master`

Data type: `String`

The LDAP Master server

* Will default to the **last** entry in ``ldap_uri`` if not set

Default value: `simplib::lookup('simp_options::ldap::master', { 'default_value'  => undef })`

##### `is_server`

Data type: `Boolean`

Set this if you want to create an OpenLDAP server on your node

Default value: ``false``

##### `pki`

Data type: `Variant[Boolean, Enum['simp']]`

* If 'simp', include SIMP's pki module and use pki::copy to manage
  application certs in /etc/pki/simp_apps/openldap/x509
* If true, do *not* include SIMP's pki module, but still use pki::copy
  to manage certs in /etc/pki/simp_apps/openldap/x509
* If false, do not include SIMP's pki module and do not use pki::copy
  to manage certs.  You will need to appropriately assign a subset of:
  * app_pki_dir
  * app_pki_key
  * app_pki_cert
  * app_pki_ca
  * app_pki_ca_dir

Default value: `simplib::lookup('simp_options::pki', { 'default_value' => false })`

##### `app_pki_external_source`

Data type: `String`

* If pki = 'simp' or true, this is the directory from which certs will be
  copied, via pki::copy.  Defaults to /etc/pki/simp/x509.

* If pki = false, this variable has no effect.

Default value: `simplib::lookup('simp_options::pki::source', { 'default_value' => '/etc/pki/simp/x509' })`

##### `app_pki_dir`

Data type: `Stdlib::Absolutepath`

This variable controls the basepath of $app_pki_key, $app_pki_cert,
$app_pki_ca, $app_pki_ca_dir, and $app_pki_crl.
It defaults to /etc/pki/simp_apps/openldap/x509.

Default value: `'/etc/pki/simp_apps/openldap/x509'`

##### `app_pki_key`

Data type: `Stdlib::AbsolutePath`

Path and name of the private SSL key file.

Default value: `"${app_pki_dir}/private/${facts['fqdn']}.pem"`

##### `app_pki_cert`

Data type: `Stdlib::AbsolutePath`

Path and name of the public SSL certificate.

Default value: `"${app_pki_dir}/public/${facts['fqdn']}.pub"`

##### `app_pki_ca_dir`

Data type: `Stdlib::AbsolutePath`

Path to the CA.

Default value: `"${app_pki_dir}/cacerts"`

##### `app_pki_crl`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the CRL file.

Default value: ``undef``

### `simp_openldap::client`

Set up /etc/openldap/ldap.conf with the global options for accessing the LDAP
servers.

Regarding: POODLE - CVE-2014-3566

The ``tls_cipher_suite`` parameter is set to ``HIGH:-SSLv2`` because OpenLDAP
cannot set the SSL provider natively.

By default, it will run TLSv1 but cannot handle TLSv1.2 therefore the SSLv3
ciphers cannot be eliminated. Take care to ensure that your clients only
connect with TLSv1 if possible.

* **See also**
  * ldap.conf(5)
    * for details.

#### Parameters

The following parameters are available in the `simp_openldap::client` class.

##### `use_tls`

Data type: `Variant[Enum['simp'],Boolean]`

Use TLS when connecting to the ldap server. By default this will mirror
simp_options::pki, but needs to be distinct as the client and server
configurations could vary.

Default value: `$::simp_openldap::pki`

##### `app_pki_key`

Data type: `Stdlib::Absolutepath`

Path and name of the private SSL key file

Default value: `$::simp_openldap::app_pki_key`

##### `app_pki_cert`

Data type: `Stdlib::Absolutepath`

Path and name of the public SSL certificate

Default value: `$::simp_openldap::app_pki_cert`

##### `app_pki_ca_dir`

Data type: `Stdlib::Absolutepath`

Path to the CA.

Default value: `$::simp_openldap::app_pki_ca_dir`

##### `app_pki_crl`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the CRL file.

Default value: `$::simp_openldap::app_pki_crl`

##### `strip_128_bit_ciphers`

Data type: `Boolean`

On EL6 systems, all 128-bit ciphers will be removed from ``tls_cipher_suite``

* This is due to a bug in the LDAP client libraries that does not appear to
  honor the order of the SSL ciphers and will attempt to connect with
  128-bit ciphers and not use stronger ciphers when those are present. This
  breaks connections to securely configured LDAP servers.

Default value: ``true``

##### `openldap_clients_ensure`

Data type: `String`

The ensure status of the openldap-clients package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### `nss_pam_ldapd_ensure`

Data type: `String`

The ensure status of the nss-pam-ldapd package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### `uri`

Data type: `Array[Simplib::URI]`



Default value: `$::simp_openldap::_ldap_uri`

##### `base_dn`

Data type: `Optional[String]`



Default value: `$::simp_openldap::base_dn`

##### `bind_dn`

Data type: `String[1]`



Default value: `$::simp_openldap::bind_dn`

##### `referrals`

Data type: `Enum['on','off']`



Default value: `'on'`

##### `sizelimit`

Data type: `Integer`



Default value: `0`

##### `timelimit`

Data type: `Integer`



Default value: `15`

##### `tls_cipher_suite`

Data type: `Array[String[1]]`



Default value: `simplib::lookup('simp_options::openssl::cipher_suite', { 'default_value' => ['DEFAULT','!MEDIUM'] })`

##### `tls_crlcheck`

Data type: `Enum['none','peer','all']`



Default value: `'none'`

##### `deref`

Data type: `Enum['never','searching','finding','always']`



Default value: `'never'`

##### `tls_reqcert`

Data type: `Enum['never','allow','try','demand','hard']`



Default value: `'allow'`

### `simp_openldap::server`

Set up an OpenLDAP server

It installs the server if not already installed and bootstraps it if
necessary.

You can quickly reset the entire server by removing all files from
``/var/lib/ldap/db/*`` and then re-runing puppet. Note that this will erase
the contents of your database, so you will want to use ``slapcat`` to save
any data that you may require later for restoration.

If you need to re-bootstrap, you also must remove the file
``/etc/openldap/puppet_bootstrapped.lock`` since this is in place as a
protective measure.

Please look at the ``simp_openldap::server::access`` stanzas below so that
you can understand how to modify the access controls via puppet.

The default access settings start at ``1000`` and go through ``3000`` except
for a default entry at ``100000`` that allows users to read everything and
then denies access. These are spread this far apart so that you can easily
override and/or circumvent them to your site specifications.

**NOTE:** To get the bootstrap to run again, you must remove the lock file at
``/etc/openldap/puppet_bootstrapped.lock`` *and* remove the database files in
``/var/lib/ldap/db/*``.

#### Parameters

The following parameters are available in the `simp_openldap::server` class.

##### `schema_sync`

Data type: `Boolean`

Synchronize all schemas from ``$schema_source``

Default value: ``true``

##### `schema_source`

Data type: `String`

The location from which to download the schemas

Default value: `"puppet:///modules/${module_name}/etc/openldap/schema"`

##### `allow_sync`

Data type: `Boolean`

Provide the ability for other hosts to use LDAP synchronization as clients
to this server

* Class variables will need to be set according to the
  ``simp_openldap::slapo::syncprov`` class requirements

Default value: ``true``

##### `sync_dn`

Data type: `String`

The DN that is allowed to synchronize from the LDAP server

Default value: `simplib::lookup('simp_options::ldap::sync_dn', { 'default_value' => "cn=LDAPSync,ou=Hosts,${::simp_openldap::base_dn}" })`

##### `use_ppolicy`

Data type: `Boolean`

Include the default password policy overlay

Default value: ``true``

##### `use_tcpwrappers`

If true, enable tcpwrappers for slapd.

##### `tcpwrappers`

Data type: `Boolean`



Default value: `simplib::lookup('simp_options::tcpwrappers', { 'default_value' => false })`

### `simp_openldap::server::conf`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

This class configures the brunt of the ``/etc/openldap`` configuration files

Regarding: POODLE - CVE-2014-3566

Using module defaults and openldap-servers >= 2.4.40, a minimum bound of TLS
v1.2 will be set.  TLSv1 and SSLv3 ciphers will be removed from the cipher
suite.

If openldap-servers is < 2.4.40, the ``tls_cipher_suite`` parameter will
default to ``DEFAULT:!MEDIUM`` because OpenLDAP < 2.4.40 cannot ensure the SSL
provider natively. Take care to ensure that your clients only connect with
TLSv1 if possible.

* **See also**
  * slapd.conf(5)
  * slapd-bdb(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::conf` class.

##### `rootdn`

Data type: `Optional[String[1]]`

The DN of the administrative LDAP user

Default value: `simplib::lookup('simp_options::ldap::root_dn', { 'default_value' => "cn=LDAPAdmin,ou=People,${::simp_openldap::base_dn}" })`

##### `rootpw`

Data type: `Optional[String[1]]`

This is the output of ``slappasswd`` for your LDAP administrative account

Default value: ``undef``

##### `syncdn`

Data type: `String[1]`

The DN of the LDAP synchronization user

* Used for DB replication

Default value: `simplib::lookup('simp_options::ldap::sync_dn', { 'default_value' => "cn=LDAPSync,ou=Hosts,${::simp_openldap::base_dn}" })`

##### `syncpw`

Data type: `Optional[String[1]]`

This is the output of ``slappasswd`` for your LDAP sync account

Default value: `simplib::lookup('simp_options::ldap::sync_hash', { 'default_value' => undef })`

##### `binddn`

Data type: `String[1]`

The DN of the LDAP host authorization user

This user should not have the ability to do anything besides bind to the
LDAP system for further authentication

Default value: `simplib::lookup('simp_options::ldap::bind_dn', { 'default_value' => $::simp_openldap::bind_dn })`

##### `bindpw`

Data type: `Optional[String[1]]`

This is the output of ``slappasswd`` for your LDAP bind account

Default value: `simplib::lookup('simp_options::ldap::bind_hash', { 'default_value' => undef })`

##### `audit_transactions`

Data type: `Boolean`

Set OpenLDAP to audit **all** transactions in the database

* This will output an LDIF file with all details of what changed on the
  system and may contain sensitive information

Default value: ``true``

##### `audit_to_syslog`

Data type: `Boolean`

Forward all audit logs to syslog

* This may contain sensitive information

Default value: ``true``

##### `auditlog`

Data type: `Stdlib::Absolutepath`

The path to the slapd audit log

* Only effective if ``$audit_transactions`` is enabled

Default value: `'/var/log/slapd.audit'`

##### `auditlog_rotate`

Data type: `Enum['daily','weekly','monthly','yearly']`

The frequency with which the slapd audit logs should be rotated

Default value: `'daily'`

##### `auditlog_preserve`

Data type: `Integer[0]`

The number of rotated audit logs to preserve

Default value: `7`

##### `authz_policy`

Data type: `Enum['none','from','to','any']`

Set the appropriate ``authz-policy`` entry

Default value: `'to'`

##### `authz_regexp`

Data type: `Array[Struct[{
      match   => String[1],
      replace => String[1]
  }] ]`

Used to convert simple usernames to an LDAP DN for authorization

* Set to an empty Array ``[]`` to have this value ignored
* Entries will be added to the configuration file in order so order them
  from most strict to least strict in your Array
* **NOTE:** The default is fairly lenient

Default value: `[{
                                                          'match'   => '^uid=([^,]+),.*',
                                                          'replace' => "uid=\$1,ou=People,${::simp_openldap::base_dn}"
                                                        }]`

##### `default_schemas`

Data type: `Array[String[1]]`

The default schemas from ``/etc/openldap/schema`` to include

* ``/etc/openldap/schema`` will be **prepended** and ``.schema`` will be
  **appended**
* It is highly recommended that you keep the default list
* If you decide to override, these defaults will *not* be merged with what
  you provide
* ``Core``, ``Cosine``, ``InetOrgPerson``, and ``NIS`` will always be
  included

Default value: `[ 'openssh-lpk', 'freeradius', 'autofs' ]`

##### `trusted_nets`

Data type: `Simplib::Netlist`

The networks that should be allowed into the server

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

##### `force_log_quick_kill`

Data type: `Boolean`

Create an ``incron`` job that will **immediately** destroy any recovery log
file written to the log directory

* Setting this is not recommended but can be used on systems where you have
  issues with recovery log size and the way that OpenLDAP manages them

Default value: ``false``

##### `include_chain_overlay`

Data type: `Boolean`

Include a chain overlay to allow for referral chaining

* This is only needed on LDAP replicant nodes

Default value: ``false``

##### `master`

Data type: `Optional[String[1]]`

If ``include_chain_overlay`` is set, then this is the upstream master that
will be used for referral chaining

Default value: `$::simp_openldap::_ldap_master`

##### `listen_ldap`

Data type: `Boolean`

Listen on the default LDAP port for ``ldap://`` conenctions

Default value: ``true``

##### `listen_ldapi`

Data type: `Boolean`

Listen on the default LDAP port for ``ldapi://`` conenctions

Default value: ``true``

##### `listen_ldaps`

Data type: `Boolean`

Listen on the default LDAPS port for ``ldaps://`` conenctions

Default value: ``true``

##### `custom_options`

Data type: `Array[String]`

Command line options that will be placed into the openldap configuration
file

* These are **not** validated for correct functionality!

Default value: `[]`

##### `password_hash`

Data type: `Enum['SSHA','SHA','SMD5','MD5','CRYPT','CLEARTEXT']`

The hash algorithm to use for passwords

Default value: `'SSHA'`

##### `sizelimit`

Data type: `Variant[Enum['unlimited'], Integer[1]]`

The default size limit for queries

* If any of the ``$sizelimit_*`` options are set, this will be overridden
  in ``slapd.conf``

Default value: `500`

##### `sizelimit_soft`

Data type: `Optional[Variant[Enum['unlimited'], Integer[1]]]`

Corresponds to ``size.soft`` in ``slapd.conf``

Default value: ``undef``

##### `sizelimit_hard`

Data type: `Optional[Variant[Enum['unlimited'], Integer[1]]]`

Corresponds to ``size.hard`` in ``slapd.conf``

Default value: ``undef``

##### `sizelimit_unchecked`

Data type: `Optional[Variant[Enum['unlimited'], Integer[1]]]`

Corresponds to ``size.unchecked`` in ``slapd.conf``

Default value: ``undef``

##### `slapd_shutdown_timeout`

Data type: `Integer[0]`

Maximum allowed time to wait for slapd shutdown (in seconds)

Default value: `3`

##### `threads`

Data type: `Variant[Enum['dynamic'],Integer[1]]`

Set the number of threads to run

* ``dynamic`` sets the limit to ``4 * processorcount``
* There is a default minimum of ``8`` and a max of ``16``

Default value: `'dynamic'`

##### `timelimit`

Data type: `Variant[Enum['unlimited'], Integer[1]]`

The default time limit for queries (in seconds)

* If any of the ``$timelimit_*`` options are set, this will be overridden
  in ``slapd.conf``

Default value: `3600`

##### `timelimit_soft`

Data type: `Optional[Variant[Enum['unlimited'], Integer[1]]]`

Corresponds to ``time.soft`` in ``slapd.conf``

Default value: ``undef``

##### `timelimit_hard`

Data type: `Optional[Variant[Enum['unlimited'], Integer[1]]]`

Corresponds to ``time.hard`` in ``slapd.conf``

Default value: ``undef``

##### `tls_protocol_min`

Data type: `Optional[Float]`

This option is only compatible with openldap-servers >= 2.4.40.

From the slapd.conf man page:
Specifies minimum SSL/TLS protocol version that will be negotiated.  If the
server doesn't  support at least that version, the SSL handshake will fail.
To require TLS 1.x or higher, set this option to 3.(x+1), e.g.,

  TLSProtocolMin 3.2

would require TLS 1.1.

Default value: ``undef``

##### `tls_verify_client`

Data type: `Enum['never','allow','try','demand','hard','true']`

TLS client verification level

Do not set this more restrictive than 'try' unless you **really** know what
you are doing and have exensively tested it in your environment

Default value: `'allow'`

##### `db_cachesize`

Data type: `Pattern['^\d+\s\d+\s\d+$']`

Set the BDB backend cache size

* The format is ``<gigabytes> <bytes> <segements>``

Default value: `'0 268435456 1'`

##### `db_log_autoremove`

Data type: `Boolean`

Tells the OpenLDAP BDB back end database to automatically remove all
recovery log files when possible

* Setting this means that you are responsible for backing up your database
  and that incremental recovery may not be possible

Default value: ``true``

##### `ulimit_max_open_files`

Data type: `Integer[1024]`

Set the number of open file handles that OpenLDAP may use

Default value: `81920`

##### `syslog`

Data type: `Boolean`

Enable the SIMP logging infrastructure

Default value: `simplib::lookup('simp_options::syslog', {'default_value' => false })`

##### `logrotate`

Data type: `Boolean`

Enable the SIMP log rotate infrastructure

Default value: `simplib::lookup('simp_options::logrotate', {'default_value' => false })`

##### `log_to_file`

Data type: `Boolean`

Send the output logs to the file specified in ``$log_file``

* Has no effect if ``$syslog`` is not set

Default value: ``false``

##### `log_file`

Data type: `Stdlib::Absolutepath`

Output all logs to this file via syslog

* Has no effect if ``$log_to_file`` is not set

Default value: `'/var/log/slapd.log'`

##### `forward_all_logs`

Data type: `Boolean`

Forward **all** OpenLDAP logs via syslog

* Has no effect if ``$syslog`` is not set

Default value: ``false``

##### `firewall`

Data type: `Boolean`

Enable the SIMP firewall

Default value: `simplib::lookup('simp_options::firewall', {'default_value' => false })`

##### `use_tls`

Data type: `Variant[Enum['simp'],Boolean]`

Enable TLS in openldap. By default this will mirror simp_options::pki,
but needs to be distinct as the client and server configurations could vary.

Default value: `$::simp_openldap::pki`

##### `app_pki_key`

Data type: `Stdlib::Absolutepath`

Path and name of the private SSL key file

Default value: `$::simp_openldap::app_pki_key`

##### `app_pki_cert`

Data type: `Stdlib::Absolutepath`

Path and name of the public SSL certificate

Default value: `$::simp_openldap::app_pki_cert`

##### `app_pki_ca_dir`

Data type: `Stdlib::Absolutepath`

Path to the CA.

Default value: `$::simp_openldap::app_pki_ca_dir`

##### `app_pki_crl`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the CRL file.

Default value: `$::simp_openldap::app_pki_crl`

##### `suffix`

Data type: `String[1]`



Default value: `$::simp_openldap::base_dn`

##### `argsfile`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/run/openldap/slapd.args'`

##### `bind_anon`

Data type: `Boolean`



Default value: ``false``

##### `cachesize`

Data type: `Integer[1]`



Default value: `10000`

##### `checkpoint`

Data type: `Pattern['(^\d+\s\d+$|^$)']`



Default value: `'1024 5'`

##### `concurrency`

Data type: `Optional[Integer[1]]`



Default value: ``undef``

##### `conn_max_pending`

Data type: `Integer[1]`



Default value: `100`

##### `conn_max_pending_auth`

Data type: `Integer[1]`



Default value: `1000`

##### `default_searchbase`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `disallow`

Data type: `Array[Simp_Openldap::SlapdConf::Disallow]`



Default value: `['bind_anon','tls_2_anon']`

##### `ditcontentrule`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `gentlehup`

Data type: `Boolean`



Default value: ``false``

##### `idletimeout`

Data type: `Integer[0]`



Default value: `0`

##### `index_substr_any_step`

Data type: `Integer[0]`



Default value: `2`

##### `index_substr_any_len`

Data type: `Integer[0]`



Default value: `4`

##### `index_substr_if_maxlen`

Data type: `Integer[0]`



Default value: `4`

##### `index_substr_if_minlen`

Data type: `Integer[0]`



Default value: `2`

##### `index_intlen`

Data type: `Integer[0]`



Default value: `4`

##### `slapd_log_level`

Data type: `Array[Simp_Openldap::LogLevel]`



Default value: `['stats', 'sync']`

##### `password_crypt_salt_format`

Data type: `String[1]`



Default value: `'%s'`

##### `pidfile`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/run/openldap/slapd.pid'`

##### `reverse_lookup`

Data type: `Boolean`



Default value: ``false``

##### `schemadn`

Data type: `String[1]`



Default value: `'cn=Subschema'`

##### `security`

Data type: `Array[String[1]]`



Default value: `['ssf=256', 'tls=256', 'update_ssf=256', 'simple_bind=256', 'update_tls=256']`

##### `sockbuf_max_incoming`

Data type: `Integer[1]`



Default value: `262143`

##### `sockbuf_max_incoming_auth`

Data type: `Integer[1]`



Default value: `4194303`

##### `sortvals`

Data type: `Array[String]`



Default value: `[]`

##### `tcp_buffer`

Data type: `Optional[Integer]`



Default value: ``undef``

##### `writetimeout`

Data type: `Integer[0]`



Default value: `0`

##### `tls_cipher_suite`

Data type: `Optional[Array[String[1]]]`



Default value: ``undef``

##### `tls_crl_check`

Data type: `Enum['none','peer','all']`



Default value: `'none'`

##### `database`

Data type: `String[1]`



Default value: `'bdb'`

##### `directory`

Data type: `Stdlib::Absolutepath`



Default value: `'/var/lib/ldap'`

##### `db_add_content_acl`

Data type: `Boolean`



Default value: ``false``

##### `db_lastmod`

Data type: `Boolean`



Default value: ``true``

##### `db_maxderefdepth`

Data type: `Integer[1]`



Default value: `15`

##### `db_mirrormode`

Data type: `Boolean`



Default value: ``false``

##### `db_monitoring`

Data type: `Boolean`



Default value: ``true``

##### `db_readonly`

Data type: `Boolean`



Default value: ``false``

##### `db_max_locks`

Data type: `Integer[1]`



Default value: `3000`

##### `db_max_lock_objects`

Data type: `Integer[1]`



Default value: `1500`

##### `db_max_lock_lockers`

Data type: `Integer[1]`



Default value: `1500`

##### `db_log_region_max_size`

Data type: `Integer[1]`



Default value: `262144`

##### `db_log_buffer_size`

Data type: `Integer[1]`



Default value: `2097152`

### `simp_openldap::server::conf::default_ldif`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

This allows for the modification of the default LDIF entries in
/etc/openldap/default.ldif. It will **not** modify any active values in a
running LDAP server.

#### Parameters

The following parameters are available in the `simp_openldap::server::conf::default_ldif` class.

##### `users_group_id`

Data type: `Integer[1]`



Default value: `100`

##### `administrators_group_id`

Data type: `Integer[500]`



Default value: `700`

##### `ppolicy_pwd_min_age`

Data type: `Integer[0]`



Default value: `86400`

##### `ppolicy_pwd_max_age`

Data type: `Integer[1]`



Default value: `15552000`

##### `ppolicy_pwd_in_history`

Data type: `Integer[0]`



Default value: `24`

##### `ppolicy_pwd_check_quality`

Data type: `Integer[0]`



Default value: `2`

##### `ppolicy_pwd_min_length`

Data type: `Integer[0]`



Default value: `14`

##### `ppolicy_pwd_expire_warning`

Data type: `Integer[0]`



Default value: `1209600`

##### `ppolicy_pwd_grace_authn_limit`

Data type: `Integer`



Default value: `-`

##### `ppolicy_pwd_lockout`

Data type: `Boolean`



Default value: ``true``

##### `ppolicy_pwd_lockout_duration`

Data type: `Integer[0]`



Default value: `900`

##### `ppolicy_pwd_max_failure`

Data type: `Integer[0]`



Default value: `5`

##### `ppolicy_pwd_failure_count_interval`

Data type: `Integer[0]`



Default value: `900`

##### `ppolicy_pwd_must_change`

Data type: `Boolean`



Default value: ``true``

##### `ppolicy_pwd_allow_user_change`

Data type: `Boolean`



Default value: ``true``

##### `ppolicy_pwd_safe_modify`

Data type: `Boolean`



Default value: ``false``

### `simp_openldap::server::fix_bad_upgrade`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

We're not ready for using slapd.d

Occasionally, the updated openldap RPM packages come out with an automatic
upgrade to slapd.d functionality.

This works around having your system destroyed by that "feature"

This pops up in the RPM updates from time to time

### `simp_openldap::server::install`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

Install the required packages

#### Parameters

The following parameters are available in the `simp_openldap::server::install` class.

##### `ensure`

Data type: `Enum['latest','installed','present']`

The state for the packages to be in

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### `simp_openldap::server::service`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

Manage the OpenLDAP service

#### Parameters

The following parameters are available in the `simp_openldap::server::service` class.

##### `slapd_svc`

Data type: `String[1]`

The actual service name

Default value: `'slapd'`

### `simp_openldap::slapo::lastbind`

This class configures lastbind and set up a dynamic include that defines lastbind.
See slapo-lastbind(5) for details of the options.

#### Parameters

The following parameters are available in the `simp_openldap::slapo::lastbind` class.

##### `lastbind_precision`

Data type: `Integer[0]`

Determines the amount of time, in seconds, after which to update the
authTimestamp entry.

Default value: `3600`

##### `lastbind_ensure`

Data type: `String`

The ensure status of packages to be managed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### `simp_openldap::slapo::ppolicy`

Configure the password policy for a site

This also includes the options for configuring the password checking plugin
that's included with SIMP.

* **See also**
  * slapo-ppolicy(5)

#### Parameters

The following parameters are available in the `simp_openldap::slapo::ppolicy` class.

##### `suffix`

Data type: `Optional[String[1]]`

The Base DN of the LDAP domain to which you wish to connect.

Default value: `$::simp_openldap::base_dn`

##### `min_points`

Data type: `Integer[0]`

The minimum number of character classes that must be included in your
password for it to succeed.

Default value: `3`

##### `use_cracklib`

Data type: `Boolean`

If true, use cracklib when checking the password.

Default value: ``true``

##### `min_upper`

Data type: `Integer[0]`

The minimum number of upper case characters that must be present for the
password to be valid.

Default value: `0`

##### `min_lower`

Data type: `Integer[0]`

The minimum number of lower case characters that must be present for the
password to be valid.

Default value: `0`

##### `min_digit`

Data type: `Integer[0]`

The minimum number of digit characters that must be present for the
password to be valid.

Default value: `0`

##### `min_punct`

Data type: `Integer[0]`

The minimum number of punctuation characters that must be present for the
password to be valid.

Default value: `0`

##### `max_consecutive_per_class`

Data type: `Integer[0]`

The maximum number of characters from any character class that can exist in
a row.

Default value: `3`

##### `ppolicy_ensure`

Data type: `String`

The ensure status of the simp-ppolicy-check-password
package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### `ppolicy_default`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `ppolicy_hash_cleartext`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `ppolicy_use_lockout`

Data type: `Optional[String[1]]`



Default value: ``undef``

### `simp_openldap::slapo::syncprov`

Allow other LDAP servers to synchronize with this one

* **See also**
  * slapo-syncprov(5)

#### Parameters

The following parameters are available in the `simp_openldap::slapo::syncprov` class.

##### `checkpoint`

Data type: `Optional[Pattern['^\d+\s\d+$']]`



Default value: ``undef``

##### `sessionlog`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `nopresent`

Data type: `Boolean`



Default value: ``false``

##### `reloadhint`

Data type: `Boolean`



Default value: ``false``

##### `sync_size_soft_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

##### `sync_size_hard_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

##### `sync_time_soft_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

##### `sync_time_hard_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

## Defined types

### `simp_openldap::server::access`

Manage access control entries in ``slapd.access``

Remember that **order matters**! Entries will be listed in alphanumeric order
after the ``$order`` parameter is processed.

* **See also**
  * slapd.access(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::access` defined type.

##### `name`

The unique name of the dynamic include. This does become part of the sort
order so be careful!

##### `comment`

Data type: `Optional[String]`

An arbitrary comment that will be included above the entry

* You do not need to include the leading `#`

Default value: ``undef``

##### `content`

Data type: `Optional[String]`

the **entire* content under ``$what``

* If you do not specify this, ``$who`` is a required variable
* If you do specify this, ``$who`` will be ignored

Default value: ``undef``

##### `order`

Data type: `Integer`

The default sort order of the entry to be added

Default value: `1000`

##### `what`

Data type: `String`



##### `who`

Data type: `Optional[String]`



Default value: ``undef``

##### `access`

Data type: `Optional[String]`



Default value: ``undef``

##### `control`

Data type: `Optional[String]`



Default value: ``undef``

### `simp_openldap::server::dynamic_include`

Add a dynamically included file into the LDAP system.

#### Parameters

The following parameters are available in the `simp_openldap::server::dynamic_include` defined type.

##### `content`

Data type: `String`

The literal content of the dynamic include

##### `order`

Data type: `Integer`

The numeric order of the dynamic include

Default value: `100`

### `simp_openldap::server::limits`

This define allows you to manage ``limits`` sections under the **main**
database

* **See also**
  * slapd.conf(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::limits` defined type.

##### `name`

A unique name for the limits entry

##### `who`

Data type: `String`

Any of the following values (not validated)
  * ``*``                          All, including anonymous and authenticated users
  * ``anonymous``                  Anonymous (non-authenticated) users
  * ``users``                      Authenticated users
  * ``self``                       User associated with target entry
  * ``dn[.<basic-style>]=<regex>`` Users matching a regular expression
  * ``dn.<scope-style>=<DN>``      Users within scope of a DN
  * ``group[/oc[/at]]=<pattern>``  Members of a group

##### `limits`

Data type: `Variant[Array[String],String]`

A list of limits to apply to ``$who`` per ``slapd.conf(5)``

### `simp_openldap::server::syncrepl`

This define configures the sycnrepl functionality of OpenLDAP which allows
for directory synchronization pulls from a master server.

$name should be the 'rid' of the syncrepl instance and must be between 0 and
1000, non-inclusive.

* **See also**
  * slapd.conf(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::syncrepl` defined type.

##### `syncrepl_retry`

Data type: `String[1]`



Default value: `'60 10 600 +'`

##### `provider`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::master', { 'default_value'  => undef })`

##### `searchbase`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::base_dn', { 'default_value' => undef })`

##### `syncrepl_type`

Data type: `Enum['refreshOnly','refreshAndPersist']`



Default value: `'refreshAndPersist'`

##### `interval`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `filter`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `syncrepl_scope`

Data type: `String[1]`



Default value: `'sub'`

##### `attrs`

Data type: `String[1]`



Default value: `'*,+'`

##### `attrsonly`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `sizelimit`

Data type: `Variant[Enum['unlimited'], Integer[0]]`



Default value: `'unlimited'`

##### `timelimit`

Data type: `Variant[Enum['unlimited'], Integer[0]]`



Default value: `'unlimited'`

##### `schemachecking`

Data type: `Enum['on','off']`



Default value: `'off'`

##### `starttls`

Data type: `Variant[Enum['critical'], Boolean]`



Default value: `'critical'`

##### `bindmethod`

Data type: `Enum['simple','sasl']`



Default value: `'simple'`

##### `binddn`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::sync_dn', {'default_value'  => undef })`

##### `saslmech`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `authcid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `authzid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `credentials`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::sync_pw', { 'default_value' => undef })`

##### `realm`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `secprops`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `logbase`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `logfilter`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### `syncdata`

Data type: `Enum['default','accesslog']`



Default value: `'default'`

##### `updateref`

Data type: `Optional[String[1]]`



Default value: ``undef``

## Data types

### `Simp_Openldap::LogLevel`

OpenLDAP Log Levels

Alias of `Variant[Integer[-1,65535], Enum[
  'any',
  '-',
  'trace',
  'packets',
  'args',
  'conns',
  'BER',
  'ber',
  'filter',
  'config',
  'ACL',
  'acl',
  'stats',
  'stats2',
  'shell',
  'parse',
  'cache',
  'index',
  'sync',
  'none'
]]`

### `Simp_Openldap::SlapdConf::Disallow`

OpenLDAP slapd.conf disallow

Alias of `Enum['bind_anon', 'bind_simple', 'tls_2_anon', 'tls_authc', 'proxy_authz_non_critical', 'dontusecopy_non_critical']`

