# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`simp_options`](#simp_options): Sets up variables that enable core SIMP capabilities or provide site configuration larger than the scope of a single module
* [`simp_options::dns`](#simp_optionsdns): Sets up DNS configuration variables
* [`simp_options::gid`](#simp_optionsgid): Provides system-wide defaults for GID settings
* [`simp_options::ldap`](#simp_optionsldap): Sets up LDAP configuration variables
* [`simp_options::ntpd`](#simp_optionsntpd): Sets up NTP configuration variables
* [`simp_options::openssl`](#simp_optionsopenssl): Sets up OpenSSL configuration variables
* [`simp_options::openssl::params`](#simp_optionsopensslparams): Sets appropriate openssl cipher suite based on whether FIPS-mode is
* [`simp_options::pki`](#simp_optionspki): Sets up global PKI configuration variables
* [`simp_options::puppet`](#simp_optionspuppet): Sets up Puppet configuration variables
* [`simp_options::rsync`](#simp_optionsrsync): Sets up ``rsync`` configuration variables
* [`simp_options::syslog`](#simp_optionssyslog): Sets up ``syslog`` configuration variables
* [`simp_options::uid`](#simp_optionsuid): Provides system-wide defaults for UID settings

## Classes

### simp_options

Sets up variables that enable core SIMP capabilities or provide site configuration larger than the scope of a single module

#### Parameters

The following parameters are available in the `simp_options` class.

##### `auditd`

Data type: `Boolean`

Include SIMP's ``auditd`` class and add audit rules pertinent to each
application

Default value: `false`

##### `clamav`

Data type: `Boolean`

Deprecated - DO NOT USE

Default value: `false`

##### `fips`

Data type: `Boolean`

Enable ``FIPS`` mode for the system

This parameter enforces strict compliance with ``FIPS-140-2``.

All core SIMP modules can support this configuration. It is important that
you know the security tradeoffs of ``FIPS-140-2`` compliance.

``FIPS`` mode disables the use of ``MD5`` and may require weaker ciphers or
key lengths than your security policies allow.

@see http://simp.readthedocs.io/en/stable/security_mapping/components/simp/cryptographic_protection/control.html SIMP - Security Control Mapping Cryptographic Protection

Default value: `false`

##### `firewall`

Data type: `Boolean`

Indicate that you want to load the native SIMP firewall management subsystem

Default value: `false`

##### `haveged`

Data type: `Boolean`

Include the ``haveged`` class to ensure adequate entropy for key
generation

@see http://simp.readthedocs.io/en/stable/getting_started_guide/Installation_Options/ISO/ISO_Build/Environment_Preparation.html?highlight=haveged SIMP - Getting Started Environment Preparation

Default value: `false`

##### `ipsec`

Data type: `Boolean`

Include SIMP's ``ipsec`` class, ``libreswan``, and add rules pertinent to
each application

Default value: `false`

##### `kerberos`

Data type: `Boolean`

Include the SIMP's Kerberos class, ``krb5``, and to use ``Kerberos`` in
applicable modules

Default value: `false`

##### `ldap`

Data type: `Boolean`

Encourage modules to use ``LDAP`` support where possible

Default value: `false`

##### `logrotate`

Data type: `Boolean`

Include SIMP's ``logrotate`` class and add rules pertinent to each
application

Default value: `false`

##### `pam`

Data type: `Boolean`

Include SIMP's ``pam`` class SIMP to manage ``PAM``

Default value: `false`

##### `pki`

Data type: `Variant[Boolean,Enum['simp']]`

Include SIMP's ``pki`` class and use ``pki::copy`` to distribute PKI
certificates to the correct locations

* If ``false``, don't include SIMP's ``pki`` class, and don't use
  ``pki::copy``
* If ``true``,  don't include SIMP's ``pki`` class, but do use ``pki::copy``
* If ``simp``, include SIMP's ``pki`` class, and use ``pki::copy``

Default value: `false`

##### `sssd`

Data type: `Boolean`

Enable ``SSSD`` support where possible

Default value: `false`

##### `stunnel`

Data type: `Boolean`

Include SIMP's ``stunnel`` class and use it to secure server-to-server
communications in applicable modules

Default value: `false`

##### `syslog`

Data type: `Boolean`

Include SIMP's ``rsyslog`` class and configure RSyslog application hooks

Default value: `false`

##### `tcpwrappers`

Data type: `Boolean`

Whether to include SIMP's ``tcpwrappers`` class and use
``tcpwrappers::allow`` to permit the application to the subnets in
``$simp_options::trusted_nets``

Default value: `false`

##### `trusted_nets`

Data type: `Simplib::Netlist`

Subnets to permit, in ``CIDR`` notation

* If you need this to be more (or less) restrictive for a given class, you
  can override it for the specific class via that class' parameters.

Default value: ['127.0.0.1', '::1']

##### `package_ensure`

Data type: `String`

The default ensure parameter for packages

* Can be either ``latest`` or ``installed``

Default value: 'latest'

##### `libkv`

Data type: `Boolean`

Enable the libkv backend for some functions

Default value: `false`

### simp_options::dns

Sets up DNS configuration variables

#### Parameters

The following parameters are available in the `simp_options::dns` class.

##### `search`

Data type: `Array[String]`

The DNS search list. Remember to put these in the appropriate
order for your environment.

Default value: []

##### `servers`

Data type: `Array[Simplib::Host]`

The list of DNS servers for the managed hosts.

If the first entry of this list is set to ``127.0.0.1``, then all clients
will configure themselves as caching DNS servers pointing to the other
entries in the list.

---------------------------------------------------------------------------
If you are using the SIMP ``resolv`` module, and the system is a DNS server
using the SIMP ``named`` module but you wish to have your node point to a
different DNS server for primary DNS resolution, then you MUST set
``resolv::named_server`` to ``true`` via Hiera.

This will get around the convenience logic that was put in place to handle
the caching entries and will not attempt to convert your system to a
caching DNS server.

---------------------------------------------------------------------------

Default value: []

### simp_options::gid

Provides system-wide defaults for GID settings

#### Parameters

The following parameters are available in the `simp_options::gid` class.

##### `min`

Data type: `Integer[0]`

The lowest allowed regular user GID for the system

Default value: pick(fact('login_defs.gid_min'), 1000)

##### `max`

Data type: `Optional[Integer[1]]`

The highest allowed regular user GID for the system

* If not defined, applications should simply do what makes sense for them
  internally

Default value: fact('login_defs.gid_max')

### simp_options::ldap

Some parameters have default values in `simp_options/data/ldap.yaml`, all
others **must** have a value specified via Hiera or your ENC.

#### Parameters

The following parameters are available in the `simp_options::ldap` class.

##### `base_dn`

Data type: `String`

The Base Distinguished Name of the LDAP server

Default value: simplib::ldap::domain_to_dn()

##### `bind_dn`

Data type: `String`

The LDAP Bind Distinguished Name

Default value: "cn=hostAuth,ou=Hosts,${base_dn}"

##### `bind_pw`

Data type: `String`

The LDAP Bind password

##### `bind_hash`

Data type: `String`

The salted LDAP Bind password hash

##### `sync_dn`

Data type: `String`

The LDAP Sync Distinguished Name

Default value: "cn=LDAPSync,ou=Hosts,${base_dn}"

##### `sync_pw`

Data type: `String`

The LDAP Sync password

##### `sync_hash`

Data type: `String`

The LDAP Sync password hash

##### `root_dn`

Data type: `String`

The LDAP Root Distinguished Name

Default value: "cn=LDAPAdmin,ou=People,${base_dn}"

##### `master`

Data type: `Simplib::URI`

The LDAP master in URI form (ldap://server)

Default value: $simp_options::puppet::server

##### `uri`

Data type: `Array[Simplib::URI]`

The list of OpenLDAP servers in URI form (ldap://server)

Default value: $master

### simp_options::ntpd

Sets up NTP configuration variables

#### Parameters

The following parameters are available in the `simp_options::ntpd` class.

##### `servers`

Data type: `Array[Simplib::Host]`

The list of NTP time servers for the network.
A consistent time source is critical to your systems' security. **DO NOT**
run multiple production systems using individual hardware clocks!

Default value: []

### simp_options::openssl

Sets up OpenSSL configuration variables

* **See also**
https://wiki.openssl.org/index.php/Command_Line_Utilities#ciphers
OpenSSL Ciphers Command

#### Parameters

The following parameters are available in the `simp_options::openssl` class.

##### `cipher_suite`

Data type: `Array[String]`

The default ciphers to use in openssl.

Default value: $::simp_options::openssl::params::cipher_suite

### simp_options::openssl::params

desired or the system is already in FIPS mode.

### simp_options::pki

Sets up global PKI configuration variables

#### Parameters

The following parameters are available in the `simp_options::pki` class.

##### `source`

Data type: `Stdlib::Absolutepath`

The source location for PKI certificates.  This is the source
directory for pki::copy.

Default value: '/etc/pki/simp/x509'

### simp_options::puppet

Sets up Puppet configuration variables

#### Parameters

The following parameters are available in the `simp_options::puppet` class.

##### `server`

Data type: `Optional[Simplib::Host]`

The ``Hostname`` or ``FQDN`` of the Puppet server

Default value: `undef`

##### `ca`

Data type: `Optional[Simplib::Host]`

The Puppet Certificate Authority

Default value: `undef`

##### `ca_port`

Data type: `Simplib::Port`

The port on which the Puppet Certificate Authority will listen

Default value: $server_distribution

##### `server_distribution`

Data type: `Simplib::Serverdistribution`

The server distribution being used, PC1 or PE.

Default value: (

### simp_options::rsync

Sets up ``rsync`` configuration variables

#### Parameters

The following parameters are available in the `simp_options::rsync` class.

##### `server`

Data type: `Simplib::Host`

Server to use for the simp::rsync_server class.

This class is used by several SIMP modules to efficiently synchronize large
data files using ``rsync`` over ``stunnel``.

The **default value** of ``127.0.0.1`` is appropriate for rsync over stunnel.

Default value: '127.0.0.1'

##### `timeout`

Data type: `Integer`

rsync connection timeout in **seconds**

Default value: 1

### simp_options::syslog

Sets up ``syslog`` configuration variables

#### Parameters

The following parameters are available in the `simp_options::syslog` class.

##### `log_servers`

Data type: `Array[Simplib::Host]`

The log servers to receive forwarded logs

Default value: []

##### `failover_log_servers`

Data type: `Array[Simplib::Host]`

Failover log servers in case your log servers fail

Default value: []

### simp_options::uid

Provides system-wide defaults for UID settings

#### Parameters

The following parameters are available in the `simp_options::uid` class.

##### `min`

Data type: `Integer[0]`

The lowest allowed regular user UID for the system

Default value: pick(fact('login_defs.uid_min'), 1000)

##### `max`

Data type: `Optional[Integer[1]]`

The highest allowed regular user UID for the system

* If not defined, applications should simply do what makes sense for them
  internally

Default value: fact('login_defs.uid_max')

